/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.StorageDebugger.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "storagedebuggeradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class StorageDebuggerAdaptor
 */

StorageDebuggerAdaptor::StorageDebuggerAdaptor(Akonadi::Server::StorageDebugger *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

StorageDebuggerAdaptor::~StorageDebuggerAdaptor()
{
    // destructor
}

QList<DbConnection> StorageDebuggerAdaptor::connections()
{
    // handle method call org.freedesktop.Akonadi.StorageDebugger.connections
    return parent()->connections();
}

void StorageDebuggerAdaptor::enableSQLDebugging(bool enable)
{
    // handle method call org.freedesktop.Akonadi.StorageDebugger.enableSQLDebugging
    parent()->enableSQLDebugging(enable);
}

bool StorageDebuggerAdaptor::isSQLDebuggingEnabled()
{
    // handle method call org.freedesktop.Akonadi.StorageDebugger.isSQLDebuggingEnabled
    return parent()->isSQLDebuggingEnabled();
}


#include "moc_storagedebuggeradaptor.cpp"
