/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Tracer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef TRACERADAPTOR_H
#define TRACERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "tracer.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Tracer
 */
class TracerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Tracer")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Tracer\">\n"
"    <method name=\"signal\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"signalName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"msg\"/>\n"
"    </method>\n"
"    <method name=\"warning\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"componentName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"msg\"/>\n"
"    </method>\n"
"    <method name=\"error\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"componentName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"msg\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    TracerAdaptor(Akonadi::Server::Tracer *parent);
    ~TracerAdaptor() override;

    inline Akonadi::Server::Tracer *parent() const
    { return static_cast<Akonadi::Server::Tracer *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void error(const QString &componentName, const QString &msg);
    void signal(const QString &signalName, const QString &msg);
    void warning(const QString &componentName, const QString &msg);
Q_SIGNALS: // SIGNALS
};

#endif
