/****************************************************************************
** Meta object code from reading C++ file 'notificationsourceinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "notificationsourceinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationsourceinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN48OrgFreedesktopAkonadiNotificationSourceInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopAkonadiNotificationSourceInterface::qt_create_metaobjectdata<qt_meta_tag_ZN48OrgFreedesktopAkonadiNotificationSourceInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopAkonadiNotificationSourceInterface",
        "ignoredSessionsChanged",
        "",
        "isAllMonitoredChanged",
        "monitoredCollectionsChanged",
        "monitoredItemsChanged",
        "monitoredMimeTypesChanged",
        "monitoredResourcesChanged",
        "monitoredTagsChanged",
        "monitoredTypesChanged",
        "ignoredSessions",
        "QDBusPendingReply<QList<QByteArray>>",
        "isAllMonitored",
        "QDBusPendingReply<bool>",
        "isExclusive",
        "monitoredCollections",
        "QDBusPendingReply<QList<qint64>>",
        "monitoredItems",
        "monitoredMimeTypes",
        "QDBusPendingReply<QStringList>",
        "monitoredResources",
        "monitoredTags",
        "monitoredTypes",
        "QDBusPendingReply<QList<Akonadi::Protocol::ChangeNotification::Typ"
        "e>>",
        "setAllMonitored",
        "QDBusPendingReply<>",
        "allMonitored",
        "setExclusive",
        "exclusive",
        "setIgnoredSession",
        "session",
        "ignored",
        "setMonitoredCollection",
        "collection",
        "monitored",
        "setMonitoredItem",
        "item",
        "setMonitoredMimeType",
        "mimetype",
        "setMonitoredResource",
        "resource",
        "setMonitoredTag",
        "tag",
        "setMonitoredType",
        "Akonadi::Protocol::ChangeNotification::Type",
        "type",
        "setSession",
        "unsubscribe"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ignoredSessionsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isAllMonitoredChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitoredCollectionsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitoredItemsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitoredMimeTypesChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitoredResourcesChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitoredTagsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitoredTypesChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ignoredSessions'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QByteArray> >()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'isAllMonitored'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(12, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'isExclusive'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(14, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'monitoredCollections'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<qint64> >()>(15, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'monitoredItems'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<qint64> >()>(17, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'monitoredMimeTypes'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'monitoredResources'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QByteArray> >()>(20, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'monitoredTags'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<qint64> >()>(21, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'monitoredTypes'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<Akonadi::Protocol::ChangeNotification::Type> >()>(22, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'setAllMonitored'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setExclusive'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(27, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setIgnoredSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QByteArray &, bool)>(29, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QByteArray, 30 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'setMonitoredCollection'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong, bool)>(32, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::LongLong, 33 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'setMonitoredItem'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong, bool)>(35, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::LongLong, 36 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'setMonitoredMimeType'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(37, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 38 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'setMonitoredResource'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QByteArray &, bool)>(39, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QByteArray, 40 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'setMonitoredTag'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong, bool)>(41, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::LongLong, 42 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'setMonitoredType'
        QtMocHelpers::SlotData<QDBusPendingReply<>(Akonadi::Protocol::ChangeNotification::Type, bool)>(43, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { 0x80000000 | 44, 45 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'setSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QByteArray &)>(46, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QByteArray, 30 },
        }}),
        // Slot 'unsubscribe'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(47, 2, QMC::AccessPublic, 0x80000000 | 25),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopAkonadiNotificationSourceInterface, qt_meta_tag_ZN48OrgFreedesktopAkonadiNotificationSourceInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopAkonadiNotificationSourceInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgFreedesktopAkonadiNotificationSourceInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgFreedesktopAkonadiNotificationSourceInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN48OrgFreedesktopAkonadiNotificationSourceInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopAkonadiNotificationSourceInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopAkonadiNotificationSourceInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ignoredSessionsChanged(); break;
        case 1: _t->isAllMonitoredChanged(); break;
        case 2: _t->monitoredCollectionsChanged(); break;
        case 3: _t->monitoredItemsChanged(); break;
        case 4: _t->monitoredMimeTypesChanged(); break;
        case 5: _t->monitoredResourcesChanged(); break;
        case 6: _t->monitoredTagsChanged(); break;
        case 7: _t->monitoredTypesChanged(); break;
        case 8: { QDBusPendingReply<QList<QByteArray>> _r = _t->ignoredSessions();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QByteArray>>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<bool> _r = _t->isAllMonitored();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<bool> _r = _t->isExclusive();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QList<qint64>> _r = _t->monitoredCollections();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<qint64>>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QList<qint64>> _r = _t->monitoredItems();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<qint64>>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QStringList> _r = _t->monitoredMimeTypes();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QList<QByteArray>> _r = _t->monitoredResources();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QByteArray>>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QList<qint64>> _r = _t->monitoredTags();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<qint64>>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QList<Akonadi::Protocol::ChangeNotification::Type>> _r = _t->monitoredTypes();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<Akonadi::Protocol::ChangeNotification::Type>>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->setAllMonitored((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->setExclusive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->setIgnoredSession((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->setMonitoredCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->setMonitoredItem((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->setMonitoredMimeType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->setMonitoredResource((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->setMonitoredTag((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->setMonitoredType((*reinterpret_cast<std::add_pointer_t<Akonadi::Protocol::ChangeNotification::Type>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->setSession((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->unsubscribe();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiNotificationSourceInterface::*)()>(_a, &OrgFreedesktopAkonadiNotificationSourceInterface::ignoredSessionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiNotificationSourceInterface::*)()>(_a, &OrgFreedesktopAkonadiNotificationSourceInterface::isAllMonitoredChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiNotificationSourceInterface::*)()>(_a, &OrgFreedesktopAkonadiNotificationSourceInterface::monitoredCollectionsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiNotificationSourceInterface::*)()>(_a, &OrgFreedesktopAkonadiNotificationSourceInterface::monitoredItemsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiNotificationSourceInterface::*)()>(_a, &OrgFreedesktopAkonadiNotificationSourceInterface::monitoredMimeTypesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiNotificationSourceInterface::*)()>(_a, &OrgFreedesktopAkonadiNotificationSourceInterface::monitoredResourcesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiNotificationSourceInterface::*)()>(_a, &OrgFreedesktopAkonadiNotificationSourceInterface::monitoredTagsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiNotificationSourceInterface::*)()>(_a, &OrgFreedesktopAkonadiNotificationSourceInterface::monitoredTypesChanged, 7))
            return;
    }
}

const QMetaObject *OrgFreedesktopAkonadiNotificationSourceInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAkonadiNotificationSourceInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgFreedesktopAkonadiNotificationSourceInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAkonadiNotificationSourceInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAkonadiNotificationSourceInterface::ignoredSessionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OrgFreedesktopAkonadiNotificationSourceInterface::isAllMonitoredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OrgFreedesktopAkonadiNotificationSourceInterface::monitoredCollectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OrgFreedesktopAkonadiNotificationSourceInterface::monitoredItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OrgFreedesktopAkonadiNotificationSourceInterface::monitoredMimeTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OrgFreedesktopAkonadiNotificationSourceInterface::monitoredResourcesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OrgFreedesktopAkonadiNotificationSourceInterface::monitoredTagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void OrgFreedesktopAkonadiNotificationSourceInterface::monitoredTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
