/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Server.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SERVERADAPTOR_H
#define SERVERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "akonadi.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Server
 */
class ServerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Server")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Server\">\n"
"    <method name=\"quit\"/>\n"
"    <method name=\"serverPath\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"path\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    ServerAdaptor(Akonadi::Server::AkonadiServer *parent);
    ~ServerAdaptor() override;

    inline Akonadi::Server::AkonadiServer *parent() const
    { return static_cast<Akonadi::Server::AkonadiServer *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void quit();
    QString serverPath();
Q_SIGNALS: // SIGNALS
};

#endif
