/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.Agent.Search.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SEARCHADAPTOR_H
#define SEARCHADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "agentsearchinterface_p.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Akonadi.Agent.Search
 */
class Akonadi__SearchAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Agent.Search")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Akonadi.Agent.Search\">\n"
"    <method name=\"addSearch\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"query\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"queryLanguage\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"destination\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"removeSearch\">\n"
"      <arg direction=\"in\" type=\"x\" name=\"destination\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"search\">\n"
"      <arg direction=\"in\" type=\"ay\" name=\"searchId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"query\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"collection\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    Akonadi__SearchAdaptor(Akonadi::AgentSearchInterfacePrivate *parent);
    ~Akonadi__SearchAdaptor() override;

    inline Akonadi::AgentSearchInterfacePrivate *parent() const
    { return static_cast<Akonadi::AgentSearchInterfacePrivate *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    Q_NOREPLY void addSearch(const QString &query, const QString &queryLanguage, qlonglong destination);
    Q_NOREPLY void removeSearch(qlonglong destination);
    Q_NOREPLY void search(const QByteArray &searchId, const QString &query, qlonglong collection);
Q_SIGNALS: // SIGNALS
};

#endif
