/****************************************************************************
** Meta object code from reading C++ file 'statusinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "statusinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statusinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN41OrgFreedesktopAkonadiAgentStatusInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopAkonadiAgentStatusInterface::qt_create_metaobjectdata<qt_meta_tag_ZN41OrgFreedesktopAkonadiAgentStatusInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopAkonadiAgentStatusInterface",
        "advancedStatus",
        "",
        "QVariantMap",
        "status",
        "error",
        "message",
        "onlineChanged",
        "state",
        "percent",
        "warning",
        "isOnline",
        "QDBusPendingReply<bool>",
        "progress",
        "QDBusPendingReply<int>",
        "setOnline",
        "Q_NOREPLY",
        "statusMessage",
        "QDBusPendingReply<QString>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'advancedStatus'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'onlineChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'percent'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'status'
        QtMocHelpers::SignalData<void(int, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'warning'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'isOnline'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(11, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'progress'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'setOnline'
        QtMocHelpers::SlotData<void(bool)>(15, 16, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'status'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(4, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'statusMessage'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopAkonadiAgentStatusInterface, qt_meta_tag_ZN41OrgFreedesktopAkonadiAgentStatusInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopAkonadiAgentStatusInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN41OrgFreedesktopAkonadiAgentStatusInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN41OrgFreedesktopAkonadiAgentStatusInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN41OrgFreedesktopAkonadiAgentStatusInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopAkonadiAgentStatusInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopAkonadiAgentStatusInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->advancedStatus((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->onlineChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->percent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->status((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->warning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { QDBusPendingReply<bool> _r = _t->isOnline();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<int> _r = _t->progress();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setOnline((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: { QDBusPendingReply<int> _r = _t->status();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QString> _r = _t->statusMessage();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentStatusInterface::*)(const QVariantMap & )>(_a, &OrgFreedesktopAkonadiAgentStatusInterface::advancedStatus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentStatusInterface::*)(const QString & )>(_a, &OrgFreedesktopAkonadiAgentStatusInterface::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentStatusInterface::*)(bool )>(_a, &OrgFreedesktopAkonadiAgentStatusInterface::onlineChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentStatusInterface::*)(int )>(_a, &OrgFreedesktopAkonadiAgentStatusInterface::percent, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentStatusInterface::*)(int , const QString & )>(_a, &OrgFreedesktopAkonadiAgentStatusInterface::status, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiAgentStatusInterface::*)(const QString & )>(_a, &OrgFreedesktopAkonadiAgentStatusInterface::warning, 5))
            return;
    }
}

const QMetaObject *OrgFreedesktopAkonadiAgentStatusInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAkonadiAgentStatusInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN41OrgFreedesktopAkonadiAgentStatusInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAkonadiAgentStatusInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAkonadiAgentStatusInterface::advancedStatus(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgFreedesktopAkonadiAgentStatusInterface::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgFreedesktopAkonadiAgentStatusInterface::onlineChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgFreedesktopAkonadiAgentStatusInterface::percent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgFreedesktopAkonadiAgentStatusInterface::status(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void OrgFreedesktopAkonadiAgentStatusInterface::warning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
