/****************************************************************************
** Meta object code from reading C++ file 'storagejanitor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.04.2/src/server/storagejanitor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'storagejanitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi6Server14StorageJanitorE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::Server::StorageJanitor::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi6Server14StorageJanitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::Server::StorageJanitor",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.Janitor",
        "information",
        "",
        "msg",
        "done",
        "check",
        "Q_NOREPLY",
        "vacuum"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'information'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'check'
        QtMocHelpers::SlotData<void()>(7, 8, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'vacuum'
        QtMocHelpers::SlotData<void()>(9, 8, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<StorageJanitor, qt_meta_tag_ZN7Akonadi6Server14StorageJanitorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Akonadi::Server::StorageJanitor::staticMetaObject = { {
    QMetaObject::SuperData::link<AkThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server14StorageJanitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server14StorageJanitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi6Server14StorageJanitorE_t>.metaTypes,
    nullptr
} };

void Akonadi::Server::StorageJanitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorageJanitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->information((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->done(); break;
        case 2: _t->check(); break;
        case 3: _t->vacuum(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StorageJanitor::*)(const QString & )>(_a, &StorageJanitor::information, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StorageJanitor::*)()>(_a, &StorageJanitor::done, 1))
            return;
    }
}

const QMetaObject *Akonadi::Server::StorageJanitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::Server::StorageJanitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server14StorageJanitorE_t>.strings))
        return static_cast<void*>(this);
    return AkThread::qt_metacast(_clname);
}

int Akonadi::Server::StorageJanitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AkThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::Server::StorageJanitor::information(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akonadi::Server::StorageJanitor::done()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
