/****************************************************************************
** Meta object code from reading C++ file 'itemretrievalmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../akonadi-26.04.2/src/server/storage/itemretrievalmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemretrievalmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Akonadi6Server20ItemRetrievalManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Akonadi::Server::ItemRetrievalManager::qt_create_metaobjectdata<qt_meta_tag_ZN7Akonadi6Server20ItemRetrievalManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Akonadi::Server::ItemRetrievalManager",
        "requestFinished",
        "",
        "Akonadi::Server::ItemRetrievalResult",
        "result",
        "requestAdded",
        "init",
        "serviceOwnerChanged",
        "serviceName",
        "oldOwner",
        "newOwner",
        "processRequest",
        "retrievalJobFinished",
        "Akonadi::Server::AbstractItemRetrievalJob*",
        "job"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestFinished'
        QtMocHelpers::SignalData<void(const Akonadi::Server::ItemRetrievalResult &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'requestAdded'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'serviceOwnerChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'processRequest'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'retrievalJobFinished'
        QtMocHelpers::SlotData<void(Akonadi::Server::AbstractItemRetrievalJob *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemRetrievalManager, qt_meta_tag_ZN7Akonadi6Server20ItemRetrievalManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Akonadi::Server::ItemRetrievalManager::staticMetaObject = { {
    QMetaObject::SuperData::link<AkThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server20ItemRetrievalManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server20ItemRetrievalManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Akonadi6Server20ItemRetrievalManagerE_t>.metaTypes,
    nullptr
} };

void Akonadi::Server::ItemRetrievalManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemRetrievalManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestFinished((*reinterpret_cast<std::add_pointer_t<Akonadi::Server::ItemRetrievalResult>>(_a[1]))); break;
        case 1: _t->requestAdded(); break;
        case 2: _t->init(); break;
        case 3: _t->serviceOwnerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->processRequest(); break;
        case 5: _t->retrievalJobFinished((*reinterpret_cast<std::add_pointer_t<Akonadi::Server::AbstractItemRetrievalJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemRetrievalManager::*)(const Akonadi::Server::ItemRetrievalResult & )>(_a, &ItemRetrievalManager::requestFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemRetrievalManager::*)()>(_a, &ItemRetrievalManager::requestAdded, 1))
            return;
    }
}

const QMetaObject *Akonadi::Server::ItemRetrievalManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Akonadi::Server::ItemRetrievalManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Akonadi6Server20ItemRetrievalManagerE_t>.strings))
        return static_cast<void*>(this);
    return AkThread::qt_metacast(_clname);
}

int Akonadi::Server::ItemRetrievalManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AkThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Akonadi::Server::ItemRetrievalManager::requestFinished(const Akonadi::Server::ItemRetrievalResult & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Akonadi::Server::ItemRetrievalManager::requestAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
